@@ -1,5 +1,5 @@
 /* *************************************************************************
- *  Copyright 2012 Jakob Gruber <jakob.gruber@gmail.com>                   *
+ *  Copyright 2015 Jakob Gruber <jakob.gruber@gmail.com>                   *
  *                                                                         *
  *  This program is free software: you can redistribute it and/or modify   *
  *  it under the terms of the GNU General Public License as published by   *
@@ -17,28 +17,49 @@
 
 
 #include "config.h"
-#include <kaboutdata.h>
-#include <kapplication.h>
-#include <kcmdlineargs.h>
+
+#include <KAboutData>
+#include <KDBusService>
+#include <KLocalizedString>
+#include <QApplication>
+#include <QCommandLineParser>
+#include <kdelibs4configmigrator.h>
 
 #include "gui/mainwindow.h"
 
 int main(int argc, char *argv[])
 {
-    KAboutData about ("picmi",
-                      0,
-                      ki18n("Picmi"),
-                      QString("%1.%2.%3").arg(VERSION_MAJOR).arg(VERSION_MINOR).arg(VERSION_PATCH).toAscii(),
-                      ki18n("Picmi - a nonogram puzzle game"),
-                      KAboutData::License_GPL_V2,
-                      ki18n("(c) 2012 The Picmi Authors"),
-                      KLocalizedString(),
-                      "https://projects.kde.org/projects/kde/kdegames/picmi");
-    about.addAuthor(ki18n("Jakob Gruber"), ki18n("Picmi Author"), "jakob.gruber@gmail.com");
+    Kdelibs4ConfigMigrator migrate(QStringLiteral("picmi"));
+    migrate.setConfigFiles(QStringList() << QStringLiteral("picmirc"));
+    migrate.setUiFiles(QStringList() << QStringLiteral("picmiui.rc"));
+    migrate.migrate();
 
-    KCmdLineArgs::init(argc, argv, &about);
-    KApplication app;
-    KGlobal::locale()->insertCatalog( QLatin1String( "libkdegames" ));
+    QApplication app(argc, argv);
+
+
+    KAboutData about("picmi",
+                      i18n("Picmi"),
+                      QString::fromLatin1("%1.%2.%3").arg(VERSION_MAJOR)
+                                         .arg(VERSION_MINOR)
+                                         .arg(VERSION_PATCH)
+                                         .toLatin1(),
+                      i18n("Picmi - a nonogram puzzle game"),
+                      KAboutLicense::GPL_V2,
+                      i18n("(c) 2012 - 2015 The Picmi Authors"),
+                      "https://projects.kde.org/projects/kde/kdegames/picmi");
+    about.addAuthor(i18n("Jakob Gruber"), i18n("Picmi Author"), "jakob.gruber@gmail.com");
+
+
+    QCommandLineParser parser;
+    KAboutData::setApplicationData(about);
+    parser.addVersionOption();
+    parser.addHelpOption();
+    about.setupCommandLine(&parser);
+    parser.process(app);
+    about.processCommandLine(&parser);
+    KLocalizedString::setApplicationDomain("picmi");
+
+    KDBusService service;
 
     MainWindow *w = new MainWindow;
     w->show();
